GaugeRange class

Configuration for gauge range colors.

Constructors

GaugeRange({required double start, required double end, required Color color, String? label})
Creates a gauge range.
const

Properties

color Color
The color of the range.
final
end double
The end value of the range (0.0 to 1.0).
final
hashCode int
The hash code for this object.
no setterinherited
label String?
Optional label for the range.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start double
The start value of the range (0.0 to 1.0).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited