GaugeSegment class

Configuration for gauge segments.

Constructors

GaugeSegment({required double start, required double end, required Color color})
Creates a gauge segment.
const

Properties

color Color
The color of the segment.
final
end double
The end value of the segment (0.0 to 1.0).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start double
The start value of the segment (0.0 to 1.0).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited