GaugeStyle enum

The style of gauge indicator.

Inheritance
Available extensions

Values

simple → const GaugeStyle

A simple arc gauge.

ticked → const GaugeStyle

A gauge with tick marks.

segmented → const GaugeStyle

A gauge with segments.

modern → const GaugeStyle

A modern gradient gauge.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GaugeStyle>
A constant List of the values in this enum, in order of their declaration.