NeedleStyle enum

Style of needle pointer for the radial gauge.

Inheritance
Available extensions

Values

none → const NeedleStyle

No needle.

simple → const NeedleStyle

Simple line needle.

tapered → const NeedleStyle

Tapered needle (wider at base).

triangle → const NeedleStyle

Needle with a triangle shape.

diamond → const NeedleStyle

Needle with diamond shape.

flat → const NeedleStyle

Modern flat needle.

compass → const NeedleStyle

Compass-style needle.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NeedleStyle>
A constant List of the values in this enum, in order of their declaration.