RadialGaugePosition enum
The position/start angle for the radial gauge.
Values
- top → const RadialGaugePosition
-
Start from the top (12 o'clock).
- right → const RadialGaugePosition
-
Start from the right (3 o'clock).
- bottom → const RadialGaugePosition
-
Start from the bottom (6 o'clock).
- left → const RadialGaugePosition
-
Start from the left (9 o'clock).
- custom → const RadialGaugePosition
-
Custom angle (use customStartAngle).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RadialGaugePosition> - A constant List of the values in this enum, in order of their declaration.