ShapePointerConfig class

Configuration for the shape pointer.

Constructors

ShapePointerConfig({ShapePointerStyle style = ShapePointerStyle.triangle, Color color = Colors.blue, double size = 15.0, ShapePointerPosition position = ShapePointerPosition.outer, double offsetRatio = 0.0, Color? borderColor, double borderWidth = 0.0, bool hasShadow = true})
Creates a shape pointer configuration.
const

Properties

borderColor → Color?
The border color of the shape.
final
borderWidth → double
The border width.
final
color → Color
The color of the shape pointer.
final
hashCode → int
The hash code for this object.
no setterinherited
hasShadow → bool
Whether the shape casts a shadow.
final
offsetRatio → double
Offset from the default position.
final
position → ShapePointerPosition
The position of the shape pointer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
The size of the shape pointer.
final
style → ShapePointerStyle
The style of the shape pointer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited