ShapePointerStyle enum

Style of shape pointer for the radial gauge.

Inheritance
Available extensions

Values

none → const ShapePointerStyle

No shape pointer.

circle → const ShapePointerStyle

Circle shape.

triangle → const ShapePointerStyle

Triangle shape.

diamond → const ShapePointerStyle

Diamond shape.

rectangle → const ShapePointerStyle

Rectangle shape.

invertedTriangle → const ShapePointerStyle

Inverted triangle.

arrow → const ShapePointerStyle

Arrow shape.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ShapePointerStyle>
A constant List of the values in this enum, in order of their declaration.