ui/circular_percent_indicator library
Classes
- CircularPercentIndicator
- A beautiful and customizable circular percent indicator widget.
Enums
- ArcType
- The type of arc to display.
- CircularChildPosition
- Position of the child widget in the circular percent indicator.
- CircularStartAngle
- The starting position for the circular progress.
- CircularStrokeCap
- The style of the line cap for the circular progress indicator.