PointerConfig class
Configuration for the pointer widget.
Constructors
- PointerConfig({PointerStyle style = PointerStyle.triangle, Color color = Colors.red, double size = 20.0, PointerPosition position = PointerPosition.start, Widget? customPointer, Color? borderColor, double borderWidth = 0.0, bool hasShadow = true})
-
Creates a pointer configuration.
const
Properties
- borderColor → Color?
-
The border color of the pointer.
final
- borderWidth → double
-
The border width of the pointer.
final
- color → Color
-
The color of the pointer.
final
- customPointer → Widget?
-
Custom pointer widget (used when style is none but widget is provided).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasShadow → bool
-
Whether the pointer casts a shadow.
final
- position → PointerPosition
-
The position of the pointer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
The size of the pointer.
final
- style → PointerStyle
-
The style of the pointer.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited