PointerStyle enum
Style of the pointer on the gauge.
Values
- none → const PointerStyle
-
No pointer.
- triangle → const PointerStyle
-
Triangle pointer.
- diamond → const PointerStyle
-
Diamond/rhombus pointer.
- arrow → const PointerStyle
-
Arrow pointer.
- circle → const PointerStyle
-
Circle pointer.
- rectangle → const PointerStyle
-
Rectangle/bar pointer.
- invertedTriangle → const PointerStyle
-
Inverted triangle pointer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PointerStyle> - A constant List of the values in this enum, in order of their declaration.