NeedleConfig class

Configuration for the needle pointer.

Constructors

NeedleConfig({NeedleStyle style = NeedleStyle.tapered, Color color = Colors.red, double lengthRatio = 0.8, double width = 8.0, Color? knobColor, double knobRadius = 10.0, bool showKnob = true, double tailLengthRatio = 0.2, Gradient? gradient, bool hasShadow = true})
Creates a needle configuration.
const

Properties

color Color
The color of the needle.
final
gradient Gradient?
Gradient for the needle.
final
hashCode int
The hash code for this object.
no setterinherited
hasShadow bool
Whether the needle casts a shadow.
final
knobColor Color?
The color of the needle knob/center.
final
knobRadius double
The radius of the needle knob.
final
lengthRatio double
The length of the needle as a ratio of the radius (0.0 to 1.0).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showKnob bool
Whether to show the knob.
final
style NeedleStyle
The style of the needle.
final
tailLengthRatio double
The tail length ratio (for compass style).
final
width double
The width/thickness of the needle at its widest point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited